@@ -9,7 +9,7 @@ Usage example:
 
     from splurge_exceptions import SplurgeValueError, ErrorMessageFormatter
 
-    exc = SplurgeValueError(error_code="invalid-value", message="Invalid input")
+    exc = SplurgeValueError("Invalid input", error_code="invalid-value")
     fmt = ErrorMessageFormatter()
     print(fmt.format_error(exc, include_context=True))
 
@@ -19,8 +19,8 @@ Attributes:
 
 """
 
-from splurge_exceptions.core.base import SplurgeError, SplurgeSubclassError
-from splurge_exceptions.core.exceptions import (
+from .core.base import SplurgeError, SplurgeSubclassError
+from .core.exceptions import (
     SplurgeAttributeError,
     SplurgeFrameworkError,
     SplurgeImportError,
@@ -30,12 +30,13 @@ from splurge_exceptions.core.exceptions import (
     SplurgeTypeError,
     SplurgeValueError,
 )
-from splurge_exceptions.formatting.message import ErrorMessageFormatter
+from .formatting.message import ErrorMessageFormatter
 
-__version__ = "2025.0.1"
+__version__ = "2025.2.1"
 __domains__ = ["exceptions", "errors", "handlers"]
 
 __all__ = [
+    __version__,
     "SplurgeError",
     "SplurgeSubclassError",
     "SplurgeValueError",
